# List of Authors #

## Original Author ##
This Vortex Lattice and the Doublet Lattice Method is implemented and maintained by:

```
Arne Voß, Institute of Aeroelasticity, Deutsches Zentrum für Luft- und Raumfahrt e.V.

```

## Contributors ##
If you contributed to this code, please list your name and affiliation here:

```
-
```

